@@ -32,14 +32,15 @@
 #include <stdbool.h>
 #include <errno.h>
 
-#include <bluetooth/bluetooth.h>
-#include <bluetooth/hci.h>
-#include <bluetooth/hci_lib.h>
-
 #include <glib.h>
 
-#include "src/shared/util.h"
+#include "lib/bluetooth.h"
+#include "lib/hci.h"
+#include "lib/hci_lib.h"
+
 #include "btio/btio.h"
+#include "src/shared/util.h"
+#include "src/shared/queue.h"
 #include "avdtp.h"
 
 static GMainLoop *mainloop = NULL;
@@ -57,6 +58,7 @@ static uint16_t version = 0x0103;
 static guint media_player = 0;
 static guint media_recorder = 0;
 static guint idle_id = 0;
+static struct queue *lseps = NULL;
 
 static bool fragment = false;
 
@@ -141,6 +143,7 @@ static void send_command(void)
 	case CMD_DELAY:
 		avdtp_delay_report(avdtp , avdtp_stream , 250);
 		break;
+	case CMD_NONE:
 	default:
 		break;
 	}
@@ -410,7 +413,7 @@ static void connect_cb(GIOChannel *chan, GError *err, gpointer user_data)
 		return;
 	}
 
-	avdtp = avdtp_new(fd, imtu, omtu, version);
+	avdtp = avdtp_new(fd, imtu, omtu, version, lseps);
 	if (!avdtp) {
 		printf("Failed to create avdtp instance\n");
 		g_main_loop_quit(mainloop);
@@ -823,13 +826,13 @@ int main(int argc, char *argv[])
 				dev_role = AVDTP_SEP_TYPE_SINK;
 			} else {
 				usage();
-				exit(0);
+				exit(1);
 			}
 			break;
 		case 'c':
 			if (str2ba(optarg, &dst) < 0) {
 				usage();
-				exit(0);
+				exit(1);
 			}
 			break;
 		case 'l':
@@ -852,24 +855,30 @@ int main(int argc, char *argv[])
 			if (version != 0x0100 && version != 0x0102 &&
 							version != 0x0103) {
 				printf("invalid version\n");
-				exit(0);
+				exit(1);
 			}
 
 			break;
 		case 'h':
-		default:
 			usage();
 			exit(0);
+		default:
+			usage();
+			exit(1);
 		}
 	}
 
-	local_sep = avdtp_register_sep(dev_role, AVDTP_MEDIA_TYPE_AUDIO,
+	lseps = queue_new();
+
+	local_sep = avdtp_register_sep(lseps, dev_role, AVDTP_MEDIA_TYPE_AUDIO,
 					0x00, TRUE, &sep_ind, &sep_cfm, NULL);
 	if (!local_sep) {
 		printf("Failed to register sep\n");
-		exit(0);
+		exit(1);
 	}
 
+	queue_push_tail(lseps, local_sep);
+
 	if (!bacmp(&dst, BDADDR_ANY)) {
 		printf("Listening...\n");
 		io = do_listen(&err);
@@ -881,13 +890,15 @@ int main(int argc, char *argv[])
 	if (!io) {
 		printf("Failed: %s\n", err->message);
 		g_error_free(err);
-		exit(0);
+		exit(1);
 	}
 
 	g_main_loop_run(mainloop);
 
 	printf("Done\n");
 
+	queue_destroy(lseps, NULL);
+
 	avdtp_unref(avdtp);
 	avdtp = NULL;
 
